summaryrefslogtreecommitdiff
path: root/indra/newview/llpanelavatar.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llpanelavatar.h')
-rw-r--r--indra/newview/llpanelavatar.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/indra/newview/llpanelavatar.h b/indra/newview/llpanelavatar.h
index 1ed5fa4357..a03902caba 100644
--- a/indra/newview/llpanelavatar.h
+++ b/indra/newview/llpanelavatar.h
@@ -78,11 +78,11 @@ public:
* Profile tabs should close any opened panels here.
*
* Called from LLPanelProfile::onOpen() before opening new profile.
* See LLPanelpicks::onClose for example. LLPanelPicks closes picture info panel
* before new profile is displayed, otherwise new profile will
* be hidden behind picture info panel.
*/
- virtual void onClose() {}
+ virtual void onClosePanel() {}
/**
* Resets controls visibility, state, etc.
@@ -78,11 +78,11 @@ public:
*
* Called from LLPanelProfile::onOpen() before opening new profile.
- * See LLPanelpicks::onClose for example. LLPanelPicks closes picture info panel
+ * See LLPanelPicks::onClosePanel for example. LLPanelPicks closes picture info panel
* before new profile is displayed, otherwise new profile will
* be hidden behind picture info panel.